module.exports = defineTest({
	description: 'Also remove banner comments when completely tree-shaking files'
});
